summaryrefslogtreecommitdiff
path: root/include/apr_strings.h
diff options
context:
space:
mode:
authorJean-Frederic Clere <jfclere@apache.org>2001-07-25 16:09:35 +0000
committerJean-Frederic Clere <jfclere@apache.org>2001-07-25 16:09:35 +0000
commitb82ebe99b1ee10c3afe8ce3ce8c8c513ffc6e579 (patch)
treec0bd02408b15b452c3f37d7b0115d70ca462a813 /include/apr_strings.h
parentc5a0883844f8282bc76e09ea31fe542c6225e8e3 (diff)
downloadapr-b82ebe99b1ee10c3afe8ce3ce8c8c513ffc6e579.tar.gz
Change the size_t into apr_size_t (It causes problems on Solaris with gcc).
git-svn-id: https://svn.apache.org/repos/asf/apr/apr/trunk@62018 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/apr_strings.h')
-rw-r--r--include/apr_strings.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/apr_strings.h b/include/apr_strings.h
index c11c58f88..c313c71f2 100644
--- a/include/apr_strings.h
+++ b/include/apr_strings.h
@@ -198,9 +198,10 @@ APR_DECLARE_NONSTD(char *) apr_psprintf(apr_pool_t *p, const char *fmt, ...)
* destination string, we return a pointer to the terminating '\0'
* to allow us to check for truncation.
* </PRE>
* @deffunc char *apr_cpystrn(char *dst, const char *src, size_t dst_size)
*/
-APR_DECLARE(char *) apr_cpystrn(char *dst, const char *src, size_t dst_size);
+APR_DECLARE(char *) apr_cpystrn(char *dst, const char *src,
+ apr_size_t dst_size);
/**
* Strip spaces from a string
@@ -198,9 +198,10 @@ APR_DECLARE_NONSTD(char *) apr_psprintf(apr_pool_t *p, const char *fmt, ...)
* to allow us to check for truncation.
* </PRE>
- * @deffunc char *apr_cpystrn(char *dst, const char *src, size_t dst_size)
+ * @deffunc char *apr_cpystrn(char *dst, const char *src, apr_size_t dst_size)
*/